@@ -169,6 +169,8 @@ class Engine(object):
                     return function(*args, **kwds)
                 except exceptions.DbRetryTransaction as e:
                     if e.args and e.args[0]:
+                        print(e)
+                        print("**Retry Transaction. Rollback and start over")
                         _tx.rollback()
                         continue
                     retry_count += 1
@@ -249,6 +251,7 @@ class Engine(object):
             conf["database"] = database
         if "dbname" in conf:
             conf["dbname"] = database
+
         return self
 
     def set_config(self, config):
