@@ -1,3 +1,4 @@
+# table.py
 from velocity.db import exceptions
 from velocity.db.core.row import Row
 from velocity.db.core.result import Result
@@ -9,8 +10,13 @@ from velocity.db.core.decorators import (
 )
 
 
-class Query(str):
-    pass
+class Query:
+    def __init__(self, sql, params=()):
+        self.sql = sql
+        self.params = params
+
+    def __str__(self):
+        return self.sql
 
 
 class Table(object):
