@@ -3,6 +3,7 @@ import hashlib
 import decimal
 import datetime
 from velocity.db import exceptions
+from .mysql_reserved import reserved_words
 
 
 def initialize(config):
@@ -634,240 +635,3 @@ class SQL:
         BOOLEAN = "BIT"
         BINARY = "BLOB"
         INTERVAL = "INTERVAL"
-
-
-reserved_words = [
-    "ACCESSIBLE",
-    "ADD",
-    "ALL",
-    "ALTER",
-    "ANALYZE",
-    "AND",
-    "AS",
-    "ASC",
-    "ASENSITIVE",
-    "BEFORE",
-    "BETWEEN",
-    "BIGINT",
-    "BINARY",
-    "BLOB",
-    "BOTH",
-    "BY",
-    "CALL",
-    "CASCADE",
-    "CASE",
-    "CHANGE",
-    "CHAR",
-    "CHARACTER",
-    "CHECK",
-    "COLLATE",
-    "COLUMN",
-    "CONDITION",
-    "CONSTRAINT",
-    "CONTINUE",
-    "CONVERT",
-    "CREATE",
-    "CROSS",
-    "CURRENT_DATE",
-    "CURRENT_TIME",
-    "CURRENT_TIMESTAMP",
-    "CURRENT_USER",
-    "CURSOR",
-    "DATABASE",
-    "DATABASES",
-    "DAY_HOUR",
-    "DAY_MICROSECOND",
-    "DAY_MINUTE",
-    "DAY_SECOND",
-    "DEC",
-    "DECIMAL",
-    "DECLARE",
-    "DEFAULT",
-    "DELAYED",
-    "DELETE",
-    "DESC",
-    "DESCRIBE",
-    "DETERMINISTIC",
-    "DISTINCT",
-    "DISTINCTROW",
-    "DIV",
-    "DOUBLE",
-    "DROP",
-    "DUAL",
-    "EACH",
-    "ELSE",
-    "ELSEIF",
-    "ENCLOSED",
-    "ESCAPED",
-    "EXISTS",
-    "EXIT",
-    "EXPLAIN",
-    "FALSE",
-    "FETCH",
-    "FLOAT",
-    "FLOAT4",
-    "FLOAT8",
-    "FOR",
-    "FORCE",
-    "FOREIGN",
-    "FROM",
-    "FULLTEXT",
-    "GENERAL",
-    "GRANT",
-    "GROUP",
-    "HAVING",
-    "HIGH_PRIORITY",
-    "HOUR_MICROSECOND",
-    "HOUR_MINUTE",
-    "HOUR_SECOND",
-    "IF",
-    "IGNORE",
-    "IGNORE_SERVER_IDS",
-    "IN",
-    "INDEX",
-    "INFILE",
-    "INNER",
-    "INOUT",
-    "INSENSITIVE",
-    "INSERT",
-    "INT",
-    "INT1",
-    "INT2",
-    "INT3",
-    "INT4",
-    "INT8",
-    "INTEGER",
-    "INTERVAL",
-    "INTO",
-    "IS",
-    "ITERATE",
-    "JOIN",
-    "KEY",
-    "KEYS",
-    "KILL",
-    "LEADING",
-    "LEAVE",
-    "LEFT",
-    "LIKE",
-    "LIMIT",
-    "LINEAR",
-    "LINES",
-    "LOAD",
-    "LOCALTIME",
-    "LOCALTIMESTAMP",
-    "LOCK",
-    "LONG",
-    "LONGBLOB",
-    "LONGTEXT",
-    "LOOP",
-    "LOW_PRIORITY",
-    "MASTER_HEARTBEAT_PERIOD",
-    "MASTER_SSL_VERIFY_SERVER_CERT",
-    "MATCH",
-    "MAXVALUE",
-    "MEDIUMBLOB",
-    "MEDIUMINT",
-    "MEDIUMTEXT",
-    "MIDDLEINT",
-    "MINUTE_MICROSECOND",
-    "MINUTE_SECOND",
-    "MOD",
-    "MODIFIES",
-    "NATURAL",
-    "NOT",
-    "NO_WRITE_TO_BINLOG",
-    "NULL",
-    "NUMERIC",
-    "ON",
-    "OPTIMIZE",
-    "OPTION",
-    "OPTIONALLY",
-    "OR",
-    "ORDER",
-    "OUT",
-    "OUTER",
-    "OUTFILE",
-    "PRECISION",
-    "PRIMARY",
-    "PROCEDURE",
-    "PROXY",
-    "PURGE",
-    "RANGE",
-    "READ",
-    "READS",
-    "READ_WRITE",
-    "REAL",
-    "REFERENCES",
-    "REGEXP",
-    "RELAY",
-    "RELEASE",
-    "RENAME",
-    "REPEAT",
-    "REPLACE",
-    "REQUIRE",
-    "RESIGNAL",
-    "RESTRICT",
-    "RETURN",
-    "REVOKE",
-    "RIGHT",
-    "RLIKE",
-    "SCHEMA",
-    "SCHEMAS",
-    "SECOND_MICROSECOND",
-    "SELECT",
-    "SENSITIVE",
-    "SEPARATOR",
-    "SET",
-    "SHOW",
-    "SIGNAL",
-    "SLOW",
-    "SMALLINT",
-    "SPATIAL",
-    "SPECIFIC",
-    "SQL",
-    "SQLEXCEPTION",
-    "SQLSTATE",
-    "SQLWARNING",
-    "SQL_BIG_RESULT",
-    "SQL_CALC_FOUND_ROWS",
-    "SQL_SMALL_RESULT",
-    "SSL",
-    "STARTING",
-    "STRAIGHT_JOIN",
-    "TABLE",
-    "TERMINATED",
-    "THEN",
-    "TIMESTAMP",
-    "TINYBLOB",
-    "TINYINT",
-    "TINYTEXT",
-    "TO",
-    "TRAILING",
-    "TRIGGER",
-    "TRUE",
-    "UNDO",
-    "UNION",
-    "UNIQUE",
-    "UNLOCK",
-    "UNSIGNED",
-    "UPDATE",
-    "USAGE",
-    "USE",
-    "USING",
-    "UTC_DATE",
-    "UTC_TIME",
-    "UTC_TIMESTAMP",
-    "VALUES",
-    "VARBINARY",
-    "VARCHAR",
-    "VARCHARACTER",
-    "VARYING",
-    "WHEN",
-    "WHERE",
-    "WHILE",
-    "WITH",
-    "WRITE",
-    "XOR",
-    "YEAR_MONTH",
-    "ZEROFILL",
-]
